# -*- coding: utf-8 -*-

_service    = 'http://localhost/ReportinServices/ReportService2010.asmx?wsdl'
_execution  = 'http://localhost/ReportinServices/ReportExecution2005.asmx?wsdl'
_user       = 'user@domain.com'
_psw        = '@password2017'

